==> hoteldruid-mod-id_3.0.7-1.tar.gz: id/gestione_utenti.php <==
<?php

switch ($messaggio) {

case "Il <b>nome</b> dell'utente":  		$messaggio = "The <b>nama</b> of user"; break;
case "verrà cambiato da":  			$messaggio = "akan diubah dari"; break;
case "a":  					$messaggio = "menjadi"; break;
case "password conservata in chiaro":  		$messaggio = "password disimpan dengan plain text"; break;
case "password conservata criptata con md5":  	$messaggio = "password disimpan enkripsi dengan md5"; break;
case "password conservata criptata con mcrypt":	$messaggio = "password disimpan enkripsi dengan mcrypt"; break;
case "password conservata criptata con mhash":	$messaggio = "password disimpan enkripsi dengan mhash"; break;
case "Inserisci una nuova password":  		$messaggio = "Tambah password baru"; break;
case "Ripeti la password":  			$messaggio = "Ulang password kembali"; break;
case "Continua":  				$messaggio = "Lanjutkan"; break;
case "Torna indietro":  			$messaggio = "Kembali"; break;
case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Already exists</div> an user called"; break;
case "Nuova password dell'utente":  		$messaggio = "Password baru untuk user"; break;
case "<b>Non</b> è stato effettuato nessun cambiamento":	$messaggio = "<b>Tidak</b> ada perubahan dibuat"; break;
case "Esiste già un utente chiamato":  		$messaggio = "Already exists an user called"; break;
case "Inserisci una nuova password per l'utente":	$messaggio = "Tambah password baru untuk user"; break;
case "Nuova password":  			$messaggio = "Password baru"; break;
case "N°":  					$messaggio = "N°"; break;
case "nome":  					$messaggio = "nama"; break;
case "modifica":  				$messaggio = "ubah"; break;
case "password criptata con md5":  		$messaggio = "password dienkripsi dengan md5"; break;
case "password criptata con mcrypt":  		$messaggio = "password dienkripsi dengan mcrypt"; break;
case "password criptata con mhash":  		$messaggio = "password dienkripsi dengan mhash"; break;
case "Modifica gli utenti":  			$messaggio = "Ubah users"; break;
case "Aggiungi":  				$messaggio = "Tambah"; break;
case "dall'utente":  				$messaggio = "dari user"; break;
case "Importa":  				$messaggio = "Impor"; break;
case "gruppi":  				$messaggio = "grup"; break;
case "Aggiornati i gruppi dell'utente":  	$messaggio = "Grup user diperbarui"; break;
case "Gruppi dell'utente":  			$messaggio = "Group user"; break;
case "Nuovo gruppo":  				$messaggio = "Grup baru"; break;
case "Esiste già un gruppo chiamato":  		$messaggio = "Grup sudah tersedia"; break;
case "Modifica":  				$messaggio = "Ubah"; break;
case "cancella":  				$messaggio = "hapus"; break;
case "Si è sicuri di voler <b style=\"font-weight: normal; color: red;\">cancellare</b> l'utente":	$messaggio = "Anda yakin ingin <b style=\"font-weight: normal; color: red;\">menghapus</b> user"; break;
case "SI":  					$messaggio = "YA"; break;
case "NO":  					$messaggio = "TIDAK"; break;
case "Gestione Utenti":  			$messaggio = "Users Management"; break;
case "Il <b>login</b> dell'utente":  		$messaggio = "The <b>login</b> of user"; break;
case "disabilitato":  				$messaggio = "disabled"; break;
case "<div style=\"display: inline; color: red;\">non</div> inserita correttamente":	$messaggio = "<div style=\"display: inline; color: red;\">not</div> inserted correctly"; break;
case "Le nuove password non coincidono":  	$messaggio = "New passwrds do not coincide"; break;
case "Gestione degli utenti di hoteldruid":	$messaggio = "HotelDruid users management"; break;
case "Gestione degli utenti":			$messaggio = "Users management"; break;
case "login":  					$messaggio = "login"; break;
case "password":  				$messaggio = "password"; break;
case "privilegi":  				$messaggio = "privileges"; break;
case "Amministratore":  			$messaggio = "Administrator"; break;
case "Abilitare per usare altri utenti":  	$messaggio = "Enable to use other users"; break;
case "un nuovo utente chiamato":  		$messaggio = "a new user called"; break;
case "dell'utente":  				$messaggio = "to user"; break;
case "del gruppo":  				$messaggio = "to group"; break;
case "Privilegi importati":  			$messaggio = "Privileges imported"; break;
case "privilegi e personalizzazioni":  		$messaggio = "privileges and customizations"; break;
case "solo i privilegi":  			$messaggio = "only privileges"; break;
case "solo le personalizzazioni":  		$messaggio = "only customizations"; break;
case "Personalizzazioni importate":  		$messaggio = "Customizations imported"; break;
case "privilegi, personalizzazioni e gruppi":	$messaggio = "privileges, customizations and groups"; break;
case "privilegi e gruppi":  			$messaggio = "privileges and groups"; break;
case "personalizzazioni e gruppi":  		$messaggio = "customizations and groups"; break;
case "solo i gruppi":  				$messaggio = "only groups"; break;
case "Gruppi importati":  			$messaggio = "Groups imported"; break;
case "Password aggiornata":  			$messaggio = "Password updated"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-id_3.0.8-1.tar.gz: id/gestione_utenti.php <==
<?php

switch ($messaggio) {

case "Il <b>nome</b> dell'utente":  		$messaggio = "The <b>nama</b> of user"; break;
case "verrà cambiato da":  			$messaggio = "akan diubah dari"; break;
case "a":  					$messaggio = "menjadi"; break;
case "password conservata in chiaro":  		$messaggio = "password disimpan dengan plain text"; break;
case "password conservata criptata con md5":  	$messaggio = "password disimpan enkripsi dengan md5"; break;
case "password conservata criptata con mcrypt":	$messaggio = "password disimpan enkripsi dengan mcrypt"; break;
case "password conservata criptata con mhash":	$messaggio = "password disimpan enkripsi dengan mhash"; break;
case "Inserisci una nuova password":  		$messaggio = "Tambah password baru"; break;
case "Ripeti la password":  			$messaggio = "Ulang password kembali"; break;
case "Continua":  				$messaggio = "Lanjutkan"; break;
case "Torna indietro":  			$messaggio = "Kembali"; break;
case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Already exists</div> an user called"; break;
case "Nuova password dell'utente":  		$messaggio = "Password baru untuk user"; break;
case "<b>Non</b> è stato effettuato nessun cambiamento":	$messaggio = "<b>Tidak</b> ada perubahan dibuat"; break;
case "Esiste già un utente chiamato":  		$messaggio = "Already exists an user called"; break;
case "Inserisci una nuova password per l'utente":	$messaggio = "Tambah password baru untuk user"; break;
case "Nuova password":  			$messaggio = "Password baru"; break;
case "N°":  					$messaggio = "N°"; break;
case "nome":  					$messaggio = "nama"; break;
case "modifica":  				$messaggio = "ubah"; break;
case "password criptata con md5":  		$messaggio = "password dienkripsi dengan md5"; break;
case "password criptata con mcrypt":  		$messaggio = "password dienkripsi dengan mcrypt"; break;
case "password criptata con mhash":  		$messaggio = "password dienkripsi dengan mhash"; break;
case "Modifica gli utenti":  			$messaggio = "Ubah users"; break;
case "Aggiungi":  				$messaggio = "Tambah"; break;
case "dall'utente":  				$messaggio = "dari user"; break;
case "Importa":  				$messaggio = "Impor"; break;
case "gruppi":  				$messaggio = "grup"; break;
case "Aggiornati i gruppi dell'utente":  	$messaggio = "Grup user diperbarui"; break;
case "Gruppi dell'utente":  			$messaggio = "Group user"; break;
case "Nuovo gruppo":  				$messaggio = "Grup baru"; break;
case "Esiste già un gruppo chiamato":  		$messaggio = "Grup sudah tersedia"; break;
case "Modifica":  				$messaggio = "Ubah"; break;
case "cancella":  				$messaggio = "hapus"; break;
case "Si è sicuri di voler <b style=\"font-weight: normal; color: red;\">cancellare</b> l'utente":	$messaggio = "Anda yakin ingin <b style=\"font-weight: normal; color: red;\">menghapus</b> user"; break;
case "SI":  					$messaggio = "YA"; break;
case "NO":  					$messaggio = "TIDAK"; break;
case "Gestione Utenti":  			$messaggio = "Users Management"; break;
case "Il <b>login</b> dell'utente":  		$messaggio = "The <b>login</b> of user"; break;
case "disabilitato":  				$messaggio = "disabled"; break;
case "<div style=\"display: inline; color: red;\">non</div> inserita correttamente":	$messaggio = "<div style=\"display: inline; color: red;\">not</div> inserted correctly"; break;
case "Le nuove password non coincidono":  	$messaggio = "New passwrds do not coincide"; break;
case "Gestione degli utenti di hoteldruid":	$messaggio = "HotelDruid users management"; break;
case "Gestione degli utenti":			$messaggio = "Users management"; break;
case "login":  					$messaggio = "login"; break;
case "password":  				$messaggio = "password"; break;
case "privilegi":  				$messaggio = "privileges"; break;
case "Amministratore":  			$messaggio = "Administrator"; break;
case "Abilitare per usare altri utenti":  	$messaggio = "Enable to use other users"; break;
case "un nuovo utente chiamato":  		$messaggio = "a new user called"; break;
case "dell'utente":  				$messaggio = "to user"; break;
case "del gruppo":  				$messaggio = "to group"; break;
case "Privilegi importati":  			$messaggio = "Privileges imported"; break;
case "privilegi e personalizzazioni":  		$messaggio = "privileges and customizations"; break;
case "solo i privilegi":  			$messaggio = "only privileges"; break;
case "solo le personalizzazioni":  		$messaggio = "only customizations"; break;
case "Personalizzazioni importate":  		$messaggio = "Customizations imported"; break;
case "privilegi, personalizzazioni e gruppi":	$messaggio = "privileges, customizations and groups"; break;
case "privilegi e gruppi":  			$messaggio = "privileges and groups"; break;
case "personalizzazioni e gruppi":  		$messaggio = "customizations and groups"; break;
case "solo i gruppi":  				$messaggio = "only groups"; break;
case "Gruppi importati":  			$messaggio = "Groups imported"; break;
case "Password aggiornata":  			$messaggio = "Password updated"; break;
case "Password troppo debole":			$messaggio = "Password too weak"; break;
case "almeno":  				$messaggio = "at least"; break;
case "caratteri":  				$messaggio = "characters"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
